pub struct MeasurementConditions {
pub temperature_c: Option<f64>,
pub pressure_kpa: Option<f64>,
pub atmosphere: Option<String>,
}Expand description
Measurement conditions for a physical/chemical property. Kept small — this only needs enough structure to say what evidence the user must provide, not to model a general laboratory information system.
Fields
temperature_c: Option<f64>pressure_kpa: Option<f64>atmosphere: Option<String>Trait Implementations
Sourceimpl Clone for MeasurementConditions
impl Clone for MeasurementConditions
Sourcefn clone(&self) -> MeasurementConditions
fn clone(&self) -> MeasurementConditions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MeasurementConditions
impl Debug for MeasurementConditions
Sourceimpl<'de> Deserialize<'de> for MeasurementConditions
impl<'de> Deserialize<'de> for MeasurementConditions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more